==> draco-0.0.3.tar.gz: draco-0.0.3/tests/test_recommendation.py <==
import unittest

from draco.run import run
from draco.spec import Data, Field, Query, Task


def get_rec(data, query):
    query = Query.from_obj(query)
    input_task = Task(data, query)
    program = input_task.to_asp_list()
    return run(program)


def run_spec(data, spec):
    query = Query.from_vegalite(spec)
    input_task = Task(data, query)
    program = input_task.to_asp_list()
    return run(program)


spec_schema = Data(
    [
        Field("q1", "number", 100, 1),
        Field("q2", "number", 100, 1),
        Field("o1", "number", 6, 1),
        Field("n1", "string", 5, 1),
    ],
    100,
    url="data.csv",
)


class TestSpecs:
    def test_scatter(self):
        recommendation = get_rec(
            spec_schema,
            {"encoding": [{"channel": "x", "field": "q1"}, {"field": "q2"}]},
        ).as_vl()

        assert recommendation == {
            "$schema": "https://vega.github.io/schema/vega-lite/v3.json",
            "data": {"url": "data.csv"},
            "mark": "point",
            "encoding": {
                "x": {"field": "q1", "type": "quantitative", "scale": {"zero": True}},
                "y": {"field": "q2", "type": "quantitative", "scale": {"zero": True}},
            },
        }

    def test_histogram(self):
        recommendation = get_rec(
            spec_schema, {"encoding": [{"field": "q1", "bin": True, "channel": "x"}]}
        ).as_vl()

        assert recommendation == {
            "$schema": "https://vega.github.io/schema/vega-lite/v3.json",
            "data": {"url": "data.csv"},
            "mark": "bar",
            "encoding": {
                "x": {"field": "q1", "type": "quantitative", "bin": True},
                "y": {
                    "aggregate": "count",
                    "type": "quantitative",
                    "scale": {"zero": True},
                },
            },
        }

    def test_strip(self):
        recommendation = get_rec(spec_schema, {"encoding": [{"field": "q1"}]}).as_vl()

        assert recommendation == {
            "$schema": "https://vega.github.io/schema/vega-lite/v3.json",
            "data": {"url": "data.csv"},
            "mark": "tick",
            "encoding": {
                "x": {"field": "q1", "type": "quantitative", "scale": {"zero": True}}
            },
        }


class TestTypeChannel:
    def get_spec(self, t, channel):
        return {
            "mark": "point",
            "encoding": {
                "y": {"field": "q1", "type": "quantitative"},
                channel: {"field": "q2" if t == "quantitative" else "o1", "type": t},
            },
        }

    def test_q(self):
        comparisons = [("x", "size"), ("size", "color")]

        for c0, c1 in comparisons:
            a = run_spec(spec_schema, self.get_spec("quantitative", c0)).cost
            b = run_spec(spec_schema, self.get_spec("quantitative", c1)).cost

            assert a < b, f"Channel {c0} is not better than {c1}."

    def test_o(self):
        comparisons = [("x", "color"), ("color", "size")]

        for c0, c1 in comparisons:
            a = run_spec(spec_schema, self.get_spec("ordinal", c0)).cost
            b = run_spec(spec_schema, self.get_spec("ordinal", c1)).cost

            assert a < b, f"Channel {c0} is not better than {c1}."

==> draco-0.0.6.tar.gz: draco-0.0.6/tests/test_recommendation.py <==
import unittest

from draco.run import run
from draco.js import cql2asp, vl2asp
from draco.helper import data_to_asp


def get_rec(data_schema, spec):
    query = cql2asp(spec)
    return run(data_schema + query)


def run_spec(data_schema, spec):
    query = vl2asp(spec)
    return run(data_schema + query)


spec_schema = [
    'data("data.csv").',
    "num_rows(100).",
    'fieldtype("q1",number).',
    'cardinality("q1",100).',
    'entropy("q1",1).',
    'fieldtype("q2",number).',
    'cardinality("q2",100).',
    'entropy("q2",1).',
    'fieldtype("o1",number).',
    'cardinality("o1",6).',
    'entropy("o1",1).',
    'fieldtype("n1",string).',
    'cardinality("n1",5).',
    'entropy("n1",1).',
]


class TestSpecs:
    def test_scatter(self):
        recommendation = get_rec(
            spec_schema,
            {"encodings": [{"channel": "x", "field": "q1"}, {"field": "q2"}]},
        ).as_vl()

        assert recommendation == {
            "$schema": "https://vega.github.io/schema/vega-lite/v3.json",
            "data": {"url": "data.csv"},
            "mark": "point",
            "encoding": {
                "x": {"field": "q1", "type": "quantitative", "scale": {"zero": True}},
                "y": {"field": "q2", "type": "quantitative", "scale": {"zero": True}},
            },
        }

    def test_histogram(self):
        recommendation = get_rec(
            spec_schema, {"encodings": [{"field": "q1", "bin": True, "channel": "x"}]}
        ).as_vl()

        print(recommendation)
        assert recommendation == {
            "$schema": "https://vega.github.io/schema/vega-lite/v3.json",
            "data": {"url": "data.csv"},
            "mark": "bar",
            "encoding": {
                "x": {"field": "q1", "type": "quantitative", "bin": True},
                "y": {
                    "aggregate": "count",
                    "type": "quantitative",
                    "scale": {"zero": True},
                },
            },
        }

    def test_strip(self):
        recommendation = get_rec(spec_schema, {"encodings": [{"field": "q1"}]}).as_vl()

        assert recommendation == {
            "$schema": "https://vega.github.io/schema/vega-lite/v3.json",
            "data": {"url": "data.csv"},
            "mark": "tick",
            "encoding": {
                "x": {"field": "q1", "type": "quantitative", "scale": {"zero": True}}
            },
        }


class TestTypeChannel:
    def get_spec(self, t, channel):
        return {
            "mark": "point",
            "encoding": {
                "y": {"field": "q1", "type": "quantitative"},
                channel: {"field": "q2" if t == "quantitative" else "o1", "type": t},
            },
        }

    def test_q(self):
        comparisons = [("x", "size"), ("size", "color")]

        for c0, c1 in comparisons:
            a = run_spec(spec_schema, self.get_spec("quantitative", c0)).cost
            b = run_spec(spec_schema, self.get_spec("quantitative", c1)).cost

            assert a < b, f"Channel {c0} is not better than {c1}."

    def test_o(self):
        comparisons = [("x", "color"), ("color", "size")]

        for c0, c1 in comparisons:
            a = run_spec(spec_schema, self.get_spec("ordinal", c0)).cost
            b = run_spec(spec_schema, self.get_spec("ordinal", c1)).cost

            assert a < b, f"Channel {c0} is not better than {c1}."
